==> open-cluster-management-agent-model-6.6.0-sources.jar: io/fabric8/openclustermanagement/api/model/agent/v1/KlusterletAddonConfigSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.agent.v1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface KlusterletAddonConfigSpecFluent<A extends KlusterletAddonConfigSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildApplicationManager instead.
   * @return The buildable object.
   */
  @Deprecated
  public KlusterletAddonAgentConfigSpec getApplicationManager();
  public KlusterletAddonAgentConfigSpec buildApplicationManager();
  public A withApplicationManager(KlusterletAddonAgentConfigSpec applicationManager);
  public Boolean hasApplicationManager();
  public A withNewApplicationManager(Boolean enabled,String proxyPolicy);
  public KlusterletAddonConfigSpecFluent.ApplicationManagerNested<A> withNewApplicationManager();
  public KlusterletAddonConfigSpecFluent.ApplicationManagerNested<A> withNewApplicationManagerLike(KlusterletAddonAgentConfigSpec item);
  public KlusterletAddonConfigSpecFluent.ApplicationManagerNested<A> editApplicationManager();
  public KlusterletAddonConfigSpecFluent.ApplicationManagerNested<A> editOrNewApplicationManager();
  public KlusterletAddonConfigSpecFluent.ApplicationManagerNested<A> editOrNewApplicationManagerLike(KlusterletAddonAgentConfigSpec item);
  
  /**
   * This method has been deprecated, please use method buildCertPolicyController instead.
   * @return The buildable object.
   */
  @Deprecated
  public KlusterletAddonAgentConfigSpec getCertPolicyController();
  public KlusterletAddonAgentConfigSpec buildCertPolicyController();
  public A withCertPolicyController(KlusterletAddonAgentConfigSpec certPolicyController);
  public Boolean hasCertPolicyController();
  public A withNewCertPolicyController(Boolean enabled,String proxyPolicy);
  public KlusterletAddonConfigSpecFluent.CertPolicyControllerNested<A> withNewCertPolicyController();
  public KlusterletAddonConfigSpecFluent.CertPolicyControllerNested<A> withNewCertPolicyControllerLike(KlusterletAddonAgentConfigSpec item);
  public KlusterletAddonConfigSpecFluent.CertPolicyControllerNested<A> editCertPolicyController();
  public KlusterletAddonConfigSpecFluent.CertPolicyControllerNested<A> editOrNewCertPolicyController();
  public KlusterletAddonConfigSpecFluent.CertPolicyControllerNested<A> editOrNewCertPolicyControllerLike(KlusterletAddonAgentConfigSpec item);
  public A addToClusterLabels(String key,String value);
  public A addToClusterLabels(Map<String,String> map);
  public A removeFromClusterLabels(String key);
  public A removeFromClusterLabels(Map<String,String> map);
  public Map<String,String> getClusterLabels();
  public <K,V>A withClusterLabels(Map<String,String> clusterLabels);
  public Boolean hasClusterLabels();
  public String getClusterName();
  public A withClusterName(String clusterName);
  public Boolean hasClusterName();
  public String getClusterNamespace();
  public A withClusterNamespace(String clusterNamespace);
  public Boolean hasClusterNamespace();
  
  /**
   * This method has been deprecated, please use method buildIamPolicyController instead.
   * @return The buildable object.
   */
  @Deprecated
  public KlusterletAddonAgentConfigSpec getIamPolicyController();
  public KlusterletAddonAgentConfigSpec buildIamPolicyController();
  public A withIamPolicyController(KlusterletAddonAgentConfigSpec iamPolicyController);
  public Boolean hasIamPolicyController();
  public A withNewIamPolicyController(Boolean enabled,String proxyPolicy);
  public KlusterletAddonConfigSpecFluent.IamPolicyControllerNested<A> withNewIamPolicyController();
  public KlusterletAddonConfigSpecFluent.IamPolicyControllerNested<A> withNewIamPolicyControllerLike(KlusterletAddonAgentConfigSpec item);
  public KlusterletAddonConfigSpecFluent.IamPolicyControllerNested<A> editIamPolicyController();
  public KlusterletAddonConfigSpecFluent.IamPolicyControllerNested<A> editOrNewIamPolicyController();
  public KlusterletAddonConfigSpecFluent.IamPolicyControllerNested<A> editOrNewIamPolicyControllerLike(KlusterletAddonAgentConfigSpec item);
  
  /**
   * This method has been deprecated, please use method buildPolicyController instead.
   * @return The buildable object.
   */
  @Deprecated
  public KlusterletAddonAgentConfigSpec getPolicyController();
  public KlusterletAddonAgentConfigSpec buildPolicyController();
  public A withPolicyController(KlusterletAddonAgentConfigSpec policyController);
  public Boolean hasPolicyController();
  public A withNewPolicyController(Boolean enabled,String proxyPolicy);
  public KlusterletAddonConfigSpecFluent.PolicyControllerNested<A> withNewPolicyController();
  public KlusterletAddonConfigSpecFluent.PolicyControllerNested<A> withNewPolicyControllerLike(KlusterletAddonAgentConfigSpec item);
  public KlusterletAddonConfigSpecFluent.PolicyControllerNested<A> editPolicyController();
  public KlusterletAddonConfigSpecFluent.PolicyControllerNested<A> editOrNewPolicyController();
  public KlusterletAddonConfigSpecFluent.PolicyControllerNested<A> editOrNewPolicyControllerLike(KlusterletAddonAgentConfigSpec item);
  
  /**
   * This method has been deprecated, please use method buildProxyConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProxyConfig getProxyConfig();
  public ProxyConfig buildProxyConfig();
  public A withProxyConfig(ProxyConfig proxyConfig);
  public Boolean hasProxyConfig();
  public A withNewProxyConfig(String httpProxy,String httpsProxy,String noProxy);
  public KlusterletAddonConfigSpecFluent.ProxyConfigNested<A> withNewProxyConfig();
  public KlusterletAddonConfigSpecFluent.ProxyConfigNested<A> withNewProxyConfigLike(ProxyConfig item);
  public KlusterletAddonConfigSpecFluent.ProxyConfigNested<A> editProxyConfig();
  public KlusterletAddonConfigSpecFluent.ProxyConfigNested<A> editOrNewProxyConfig();
  public KlusterletAddonConfigSpecFluent.ProxyConfigNested<A> editOrNewProxyConfigLike(ProxyConfig item);
  
  /**
   * This method has been deprecated, please use method buildSearchCollector instead.
   * @return The buildable object.
   */
  @Deprecated
  public KlusterletAddonAgentConfigSpec getSearchCollector();
  public KlusterletAddonAgentConfigSpec buildSearchCollector();
  public A withSearchCollector(KlusterletAddonAgentConfigSpec searchCollector);
  public Boolean hasSearchCollector();
  public A withNewSearchCollector(Boolean enabled,String proxyPolicy);
  public KlusterletAddonConfigSpecFluent.SearchCollectorNested<A> withNewSearchCollector();
  public KlusterletAddonConfigSpecFluent.SearchCollectorNested<A> withNewSearchCollectorLike(KlusterletAddonAgentConfigSpec item);
  public KlusterletAddonConfigSpecFluent.SearchCollectorNested<A> editSearchCollector();
  public KlusterletAddonConfigSpecFluent.SearchCollectorNested<A> editOrNewSearchCollector();
  public KlusterletAddonConfigSpecFluent.SearchCollectorNested<A> editOrNewSearchCollectorLike(KlusterletAddonAgentConfigSpec item);
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public interface ApplicationManagerNested<N> extends Nested<N>,KlusterletAddonAgentConfigSpecFluent<KlusterletAddonConfigSpecFluent.ApplicationManagerNested<N>>{
    public N and();
    public N endApplicationManager();
    
  }
  public interface CertPolicyControllerNested<N> extends Nested<N>,KlusterletAddonAgentConfigSpecFluent<KlusterletAddonConfigSpecFluent.CertPolicyControllerNested<N>>{
    public N and();
    public N endCertPolicyController();
    
  }
  public interface IamPolicyControllerNested<N> extends Nested<N>,KlusterletAddonAgentConfigSpecFluent<KlusterletAddonConfigSpecFluent.IamPolicyControllerNested<N>>{
    public N and();
    public N endIamPolicyController();
    
  }
  public interface PolicyControllerNested<N> extends Nested<N>,KlusterletAddonAgentConfigSpecFluent<KlusterletAddonConfigSpecFluent.PolicyControllerNested<N>>{
    public N and();
    public N endPolicyController();
    
  }
  public interface ProxyConfigNested<N> extends Nested<N>,ProxyConfigFluent<KlusterletAddonConfigSpecFluent.ProxyConfigNested<N>>{
    public N and();
    public N endProxyConfig();
    
  }
  public interface SearchCollectorNested<N> extends Nested<N>,KlusterletAddonAgentConfigSpecFluent<KlusterletAddonConfigSpecFluent.SearchCollectorNested<N>>{
    public N and();
    public N endSearchCollector();
    
  }
  
}

==> open-cluster-management-agent-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/agent/v1/KlusterletAddonConfigSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.agent.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface KlusterletAddonConfigSpecFluent<A extends KlusterletAddonConfigSpecFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildApplicationManager instead.
   * @return The buildable object.
   */
  @Deprecated
  public KlusterletAddonAgentConfigSpec getApplicationManager();
  public KlusterletAddonAgentConfigSpec buildApplicationManager();
  public A withApplicationManager(KlusterletAddonAgentConfigSpec applicationManager);
  public Boolean hasApplicationManager();
  public A withNewApplicationManager(Boolean enabled,String proxyPolicy);
  public KlusterletAddonConfigSpecFluent.ApplicationManagerNested<A> withNewApplicationManager();
  public KlusterletAddonConfigSpecFluent.ApplicationManagerNested<A> withNewApplicationManagerLike(KlusterletAddonAgentConfigSpec item);
  public KlusterletAddonConfigSpecFluent.ApplicationManagerNested<A> editApplicationManager();
  public KlusterletAddonConfigSpecFluent.ApplicationManagerNested<A> editOrNewApplicationManager();
  public KlusterletAddonConfigSpecFluent.ApplicationManagerNested<A> editOrNewApplicationManagerLike(KlusterletAddonAgentConfigSpec item);
  
  /**
   * This method has been deprecated, please use method buildCertPolicyController instead.
   * @return The buildable object.
   */
  @Deprecated
  public KlusterletAddonAgentConfigSpec getCertPolicyController();
  public KlusterletAddonAgentConfigSpec buildCertPolicyController();
  public A withCertPolicyController(KlusterletAddonAgentConfigSpec certPolicyController);
  public Boolean hasCertPolicyController();
  public A withNewCertPolicyController(Boolean enabled,String proxyPolicy);
  public KlusterletAddonConfigSpecFluent.CertPolicyControllerNested<A> withNewCertPolicyController();
  public KlusterletAddonConfigSpecFluent.CertPolicyControllerNested<A> withNewCertPolicyControllerLike(KlusterletAddonAgentConfigSpec item);
  public KlusterletAddonConfigSpecFluent.CertPolicyControllerNested<A> editCertPolicyController();
  public KlusterletAddonConfigSpecFluent.CertPolicyControllerNested<A> editOrNewCertPolicyController();
  public KlusterletAddonConfigSpecFluent.CertPolicyControllerNested<A> editOrNewCertPolicyControllerLike(KlusterletAddonAgentConfigSpec item);
  public A addToClusterLabels(String key,String value);
  public A addToClusterLabels(Map<String,String> map);
  public A removeFromClusterLabels(String key);
  public A removeFromClusterLabels(Map<String,String> map);
  public Map<String,String> getClusterLabels();
  public <K,V>A withClusterLabels(Map<String,String> clusterLabels);
  public Boolean hasClusterLabels();
  public String getClusterName();
  public A withClusterName(String clusterName);
  public Boolean hasClusterName();
  public String getClusterNamespace();
  public A withClusterNamespace(String clusterNamespace);
  public Boolean hasClusterNamespace();
  
  /**
   * This method has been deprecated, please use method buildIamPolicyController instead.
   * @return The buildable object.
   */
  @Deprecated
  public KlusterletAddonAgentConfigSpec getIamPolicyController();
  public KlusterletAddonAgentConfigSpec buildIamPolicyController();
  public A withIamPolicyController(KlusterletAddonAgentConfigSpec iamPolicyController);
  public Boolean hasIamPolicyController();
  public A withNewIamPolicyController(Boolean enabled,String proxyPolicy);
  public KlusterletAddonConfigSpecFluent.IamPolicyControllerNested<A> withNewIamPolicyController();
  public KlusterletAddonConfigSpecFluent.IamPolicyControllerNested<A> withNewIamPolicyControllerLike(KlusterletAddonAgentConfigSpec item);
  public KlusterletAddonConfigSpecFluent.IamPolicyControllerNested<A> editIamPolicyController();
  public KlusterletAddonConfigSpecFluent.IamPolicyControllerNested<A> editOrNewIamPolicyController();
  public KlusterletAddonConfigSpecFluent.IamPolicyControllerNested<A> editOrNewIamPolicyControllerLike(KlusterletAddonAgentConfigSpec item);
  
  /**
   * This method has been deprecated, please use method buildPolicyController instead.
   * @return The buildable object.
   */
  @Deprecated
  public KlusterletAddonAgentConfigSpec getPolicyController();
  public KlusterletAddonAgentConfigSpec buildPolicyController();
  public A withPolicyController(KlusterletAddonAgentConfigSpec policyController);
  public Boolean hasPolicyController();
  public A withNewPolicyController(Boolean enabled,String proxyPolicy);
  public KlusterletAddonConfigSpecFluent.PolicyControllerNested<A> withNewPolicyController();
  public KlusterletAddonConfigSpecFluent.PolicyControllerNested<A> withNewPolicyControllerLike(KlusterletAddonAgentConfigSpec item);
  public KlusterletAddonConfigSpecFluent.PolicyControllerNested<A> editPolicyController();
  public KlusterletAddonConfigSpecFluent.PolicyControllerNested<A> editOrNewPolicyController();
  public KlusterletAddonConfigSpecFluent.PolicyControllerNested<A> editOrNewPolicyControllerLike(KlusterletAddonAgentConfigSpec item);
  
  /**
   * This method has been deprecated, please use method buildProxyConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public ProxyConfig getProxyConfig();
  public ProxyConfig buildProxyConfig();
  public A withProxyConfig(ProxyConfig proxyConfig);
  public Boolean hasProxyConfig();
  public A withNewProxyConfig(String httpProxy,String httpsProxy,String noProxy);
  public KlusterletAddonConfigSpecFluent.ProxyConfigNested<A> withNewProxyConfig();
  public KlusterletAddonConfigSpecFluent.ProxyConfigNested<A> withNewProxyConfigLike(ProxyConfig item);
  public KlusterletAddonConfigSpecFluent.ProxyConfigNested<A> editProxyConfig();
  public KlusterletAddonConfigSpecFluent.ProxyConfigNested<A> editOrNewProxyConfig();
  public KlusterletAddonConfigSpecFluent.ProxyConfigNested<A> editOrNewProxyConfigLike(ProxyConfig item);
  
  /**
   * This method has been deprecated, please use method buildSearchCollector instead.
   * @return The buildable object.
   */
  @Deprecated
  public KlusterletAddonAgentConfigSpec getSearchCollector();
  public KlusterletAddonAgentConfigSpec buildSearchCollector();
  public A withSearchCollector(KlusterletAddonAgentConfigSpec searchCollector);
  public Boolean hasSearchCollector();
  public A withNewSearchCollector(Boolean enabled,String proxyPolicy);
  public KlusterletAddonConfigSpecFluent.SearchCollectorNested<A> withNewSearchCollector();
  public KlusterletAddonConfigSpecFluent.SearchCollectorNested<A> withNewSearchCollectorLike(KlusterletAddonAgentConfigSpec item);
  public KlusterletAddonConfigSpecFluent.SearchCollectorNested<A> editSearchCollector();
  public KlusterletAddonConfigSpecFluent.SearchCollectorNested<A> editOrNewSearchCollector();
  public KlusterletAddonConfigSpecFluent.SearchCollectorNested<A> editOrNewSearchCollectorLike(KlusterletAddonAgentConfigSpec item);
  public String getVersion();
  public A withVersion(String version);
  public Boolean hasVersion();
  public interface ApplicationManagerNested<N> extends Nested<N>,KlusterletAddonAgentConfigSpecFluent<KlusterletAddonConfigSpecFluent.ApplicationManagerNested<N>>{
    public N and();
    public N endApplicationManager();
    
  }
  public interface CertPolicyControllerNested<N> extends Nested<N>,KlusterletAddonAgentConfigSpecFluent<KlusterletAddonConfigSpecFluent.CertPolicyControllerNested<N>>{
    public N and();
    public N endCertPolicyController();
    
  }
  public interface IamPolicyControllerNested<N> extends Nested<N>,KlusterletAddonAgentConfigSpecFluent<KlusterletAddonConfigSpecFluent.IamPolicyControllerNested<N>>{
    public N and();
    public N endIamPolicyController();
    
  }
  public interface PolicyControllerNested<N> extends Nested<N>,KlusterletAddonAgentConfigSpecFluent<KlusterletAddonConfigSpecFluent.PolicyControllerNested<N>>{
    public N and();
    public N endPolicyController();
    
  }
  public interface ProxyConfigNested<N> extends Nested<N>,ProxyConfigFluent<KlusterletAddonConfigSpecFluent.ProxyConfigNested<N>>{
    public N and();
    public N endProxyConfig();
    
  }
  public interface SearchCollectorNested<N> extends Nested<N>,KlusterletAddonAgentConfigSpecFluent<KlusterletAddonConfigSpecFluent.SearchCollectorNested<N>>{
    public N and();
    public N endSearchCollector();
    
  }
  
}
